@@ -12,7 +12,7 @@
 #' 
 #' @examples 
 #' cbmPlot <- PlotCbmFit(c(1, 2), c(0.5, 0.5))
-#' print(cbmPlot)
+#' ## print(cbmPlot)
 #' 
 #' 
 #' @references 
@@ -24,6 +24,7 @@
 #' @export
 
 PlotCbmFit <- function(mu, alpha){
+
   if (length(mu) != length(alpha))
     stop("The lengths of mu and alpha do not match.")
   plotZeta <- seq(-20, 20, by = 0.01)
@@ -31,7 +32,7 @@ PlotCbmFit <- function(mu, alpha){
   for (i in 1:length(mu)){
     FPF <- 1 - pnorm(plotZeta)
     TPF <- (1 - alpha[i]) * (1 - pnorm(plotZeta)) + alpha[i] * (1 - pnorm(plotZeta, mean = mu[i]))
-    plotCBM <- rbind(plotCBM, data.frame(FPF = FPF, TPF = TPF, Treatment = as.character(i)))
+    plotCBM <- rbind(plotCBM, data.frame(FPF = FPF, TPF = TPF, Treatment = as.character(i), stringsAsFactors = FALSE))
   }
   cbmROCCurve <- with(plotCBM,{
     ggplot() + geom_line(mapping = aes(x = FPF, y = TPF, color = Treatment), data = plotCBM, size = 1)
