@@ -4,51 +4,49 @@
 #'    averaged over specified treatment factor
 #' 
 #' 
-#' @param crossedData The crossed treatments dataset
+#' @param ds The crossed treatments dataset
 #' @param avgIndx The index of the treatment to be averaged over
 #' @param FOM See \code{\link{StSignificanceTesting}}
 #' @param alpha See \code{\link{StSignificanceTesting}}
-#' @param option See \code{\link{StSignificanceTesting}}
+#' @param analysisOption See \code{\link{StSignificanceTesting}}
 #' 
 #' @return The return list contains the same items with \code{\link{StSignificanceTesting}}.
 #' 
 #' @examples
-#' \donttest{ 
-#' ## read the raw data file in extdata directory
-#' crossedFileName <- system.file("extdata", "CrossedModalitiesData.xlsx", 
-#' package = "RJafroc", mustWork = TRUE)
-#' crossedData <- DfReadCrossedModalities(crossedFileName)
-#' retCrossed1 <- StSignificanceTestingCrossedModalities(crossedData, 1)
 #' 
+#' \donttest{ 
 #' ## read the built in dataset
 #' retCrossed2 <- StSignificanceTestingCrossedModalities(datasetCrossedModality, 1)
 #' }
 #' 
 #' @export
-StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "wAFROC", 
-                                                   alpha = 0.05, option = "ALL"){
-  NL <- crossedData$NL
-  LL <- crossedData$LL
-  lesionVector <- crossedData$lesionVector
-  lesionID <- crossedData$lesionID
-  lesionWeight <- crossedData$lesionWeight
+StSignificanceTestingCrossedModalities <- function(ds, avgIndx, FOM = "wAFROC", 
+                                                   alpha = 0.05, analysisOption = "ALL"){
+  
+  if (ds$descriptions$design != "FCTRL-X-MOD") stop("Dataset is not factorial crossed modality")
+  options(stringsAsFactors = FALSE)
+  NL <- ds$ratings$NL
+  LL <- ds$ratings$LL
+  perCase <- ds$lesions$perCase
+  IDs <- ds$lesions$IDs
+  weights <- ds$lesions$weights
   maxNL <- dim(NL)[5]
   maxLL <- dim(LL)[5]
-  dataType <- crossedData$dataType
+  dataType <- ds$dataType
   if(avgIndx == 1){
-    modalityID <- crossedData$modalityID2
+    modalityID <- ds$descriptions$modalityID2
   }else{
-    modalityID <- crossedData$modalityID1
+    modalityID <- ds$descriptions$modalityID1
   }
-  readerID <- crossedData$readerID
+  readerID <- ds$descriptions$readerID
   I <- length(modalityID)
   J <- length(readerID)
   K <- dim(NL)[4]
   K2 <- dim(LL)[4]
   K1 <- K - K2
   
-  if (!option %in% c("RRRC", "FRRC", "RRFC", "ALL")){
-    errMsg <- sprintf("%s is not an available option.", option)
+  if (!analysisOption %in% c("RRRC", "FRRC", "RRFC", "ALL")){
+    errMsg <- sprintf("%s is not an available analysisOption.", analysisOption)
     stop(errMsg)
   }    
   
@@ -56,12 +54,12 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
     stop("The analysis requires at least 2 treatments")
   }
   
-  ret <- EstimateVarCovCrossed(NL, LL, lesionVector, lesionID, lesionWeight, maxNL, maxLL, FOM, avgIndx)
-  var <- ret$var
-  cov1 <- ret$cov1
-  cov2 <- ret$cov2
-  cov3 <- ret$cov3
-  fomArray <- ret$fomArray
+  ret <- EstimateVarCovCrossed(NL, LL, perCase, IDs, weights, maxNL, maxLL, FOM, avgIndx)
+  Var <- ret$Var
+  Cov1 <- ret$Cov1
+  Cov2 <- ret$Cov2
+  Cov3 <- ret$Cov3
+  fomArray <- ret$fomArray  # sic! 4/29/20
   trMeans <- rowMeans(fomArray)
   fomMean <- mean(fomArray)
   
@@ -85,11 +83,14 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
   }
   msTR <- msTR/((J - 1) * (I - 1))
   
-  varTR <- msTR - var + cov1 + max(cov2 - cov3, 0)
-  varR <- (msR - var - (I - 1) * cov1 + cov2 + (I - 1) * cov3 - varTR)/I
-  varCovArray <- c(varR, varTR, cov1, cov2, cov3, var)
+  # TBA need citations here
+  varTR <- msTR - Var + Cov1 + max(Cov2 - Cov3, 0)
+  varR <- (msR - Var - (I - 1) * Cov1 + Cov2 + (I - 1) * Cov3 - varTR)/I
+  varCovArray <- c(varR, varTR, Cov1, Cov2, Cov3, Var)
   nameArray <- c("Var(R)", "Var(T*R)", "COV1", "COV2", "COV3", "Var(Error)")
-  varComp <- data.frame(varCov = varCovArray, row.names = nameArray)
+  varComp <- data.frame(varCov = varCovArray, 
+                        row.names = nameArray, 
+                        stringsAsFactors = FALSE)
   
   varSingle <- vector(length = I)
   cov2Single <- vector(length = I)
@@ -97,20 +98,20 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
     if (avgIndx == 1){
       nl <- NL[ , i, , , ]
       ll <- LL[ , i, , , ]
-      dim(nl) <- c(length(crossedData$modalityID1), 1, J, K, maxNL)
-      dim(ll) <- c(length(crossedData$modalityID1), 1, J, K2, max(lesionVector))
+      dim(nl) <- c(length(ds$descriptions$modalityID1), 1, J, K, maxNL)
+      dim(ll) <- c(length(ds$descriptions$modalityID1), 1, J, K2, max(perCase))
     }else{
       nl <- NL[ i, , , , ]
       ll <- LL[ i, , , , ]
-      dim(nl) <- c(1, length(crossedData$modalityID2), J, K, maxNL)
-      dim(ll) <- c(1, length(crossedData$modalityID2), J, K2, max(lesionVector))
+      dim(nl) <- c(1, length(ds$descriptions$modalityID2), J, K, maxNL)
+      dim(ll) <- c(1, length(ds$descriptions$modalityID2), J, K2, max(perCase))
     }
     
     
-    ret <- EstimateVarCovCrossed(nl, ll, lesionVector, lesionID, lesionWeight, maxNL, maxLL, FOM, avgIndx)
-    varSingle[i] <- ret$var
+    ret <- EstimateVarCovCrossed(nl, ll, perCase, IDs, weights, maxNL, maxLL, FOM, avgIndx)
+    varSingle[i] <- ret$Var
     if (J > 1) {
-      cov2Single[i] <- ret$cov2
+      cov2Single[i] <- ret$Cov2
     } else {
       cov2Single[i] <- 0
     }
@@ -121,11 +122,11 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
   for (j in 1:J) {
     nl <- NL[ , , j, , ]
     ll <- LL[ , , j, , ]
-    dim(nl) <- c(length(crossedData$modalityID1), length(crossedData$modalityID2), 1, K, maxNL)
-    dim(ll) <- c(length(crossedData$modalityID1), length(crossedData$modalityID2), 1, K2, max(lesionVector))
-    ret <- EstimateVarCovCrossed(nl, ll, lesionVector, lesionID, lesionWeight, maxNL, maxLL, FOM, avgIndx)
-    varEchRder[j] <- ret$var
-    cov1EchRder[j] <- ret$cov1
+    dim(nl) <- c(length(ds$descriptions$modalityID1), length(ds$descriptions$modalityID2), 1, K, maxNL)
+    dim(ll) <- c(length(ds$descriptions$modalityID1), length(ds$descriptions$modalityID2), 1, K2, max(perCase))
+    ret <- EstimateVarCovCrossed(nl, ll, perCase, IDs, weights, maxNL, maxLL, FOM, avgIndx)
+    varEchRder[j] <- ret$Var
+    cov1EchRder[j] <- ret$Cov1
   }
   
   msRSingle <- array(0, dim = c(I))
@@ -149,9 +150,9 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
   msNum <- msT
   
   # ************ RRRC ****************
-  if (option %in% c("RRRC", "ALL")) {
+  if (analysisOption %in% c("RRRC", "ALL")) {
     if (J > 1) {
-      msDenRRRC <- msTR + max(J * (cov2 - cov3), 0)
+      msDenRRRC <- msTR + max(J * (Cov2 - Cov3), 0)
       fRRRC <- msNum/msDenRRRC
       ddfRRRC <- msDenRRRC^2/(msTR^2/((I - 1) * (J - 1)))
       pRRRC <- 1 - pf(fRRRC, I - 1, ddfRRRC)
@@ -169,6 +170,17 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
           CIRRRC[i, ] <- ci
         }
       }
+      # This code was failing on oldrelease R v3.5.3 under test context("StSignificanceTestingCrossedModalities")
+      # The outputs for ciDiffTrtRRRC were not equal for goodvalues and currentvalues
+      # forcing original order to be kept
+      
+      for (i in (1:length(diffTRName))) {
+        diffTRName[i] <- paste0(paste0("Row",i,"_"),diffTRName[i])
+      }
+      
+      attributes(diffTRName) <- NULL #statement #1a
+      attributes(diffTRMeans) <- NULL #statement #1b
+      
       ciDiffTrtRRRC <- data.frame(Treatment = diffTRName, 
                                   Estimate = diffTRMeans, 
                                   StdErr = rep(stdErrRRRC, choose(I, 2)), 
@@ -176,8 +188,50 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
                                   t = tStat, 
                                   PrGTt = tPr, 
                                   CILower = CIRRRC[,1],
-                                  CIUpper = CIRRRC[,2])
-      #colnames(ciDiffTrtRRRC) <- c("Treatment", "Estimate", "StdErr", "DF", "t", "PrGTt", "CILower", "CIUpper")
+                                  CIUpper = CIRRRC[,2],
+                                  stringsAsFactors = FALSE)
+      
+      # print(attributes(ciDiffTrtRRRC))
+      # print(attributes(ciDiffTrtRRRC$Treatment))
+      # print(attributes(ciDiffTrtRRRC$Estimate))
+      # print(class(ciDiffTrtRRRC$Treatment))
+      ################################################################################
+      # this whole issue could be a git problem of not updating a regenerated new good value
+      # I had to do two commits followed by push: one with file deleted and one with file regenerated.
+      # Then all travis releases worked;
+      # if statements #1,ab IS commented
+      # $names
+      # [1] "Treatment" "Estimate"  "StdErr"    "DF"        "t"         "PrGTt"     "CILower"   "CIUpper"  
+      # 
+      # $class
+      # [1] "data.frame"
+      # 
+      # $row.names
+      # [1] 1 2 3 4 5 6
+      # 
+      # NULL
+      # NULL
+      # [1] "character"
+      
+      # if statements #1,ab is NOT commented
+      # $names
+      # [1] "Treatment" "Estimate"  "StdErr"    "DF"        "t"         "PrGTt"     "CILower"   "CIUpper"  
+      # 
+      # $class
+      # [1] "data.frame"
+      # 
+      # $row.names
+      # [1] 1 2 3 4 5 6
+      # 
+      # $levels
+      # [1] "Row1_20-40" "Row2_20-60" "Row3_20-80" "Row4_40-60" "Row5_40-80" "Row6_60-80"
+      # 
+      # $class
+      # [1] "factor"
+      # 
+      # NULL
+      # [1] "factor"    
+      ################################################################################
       
       dfSingleRRRC <- array(dim = I)
       msDenSingleRRRC <- array(dim = I)
@@ -201,8 +255,8 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
                                         DF = as.vector(dfSingleRRRC), 
                                         CILower = CISingleRRRC[,1], 
                                         CIUpper = CISingleRRRC[,2], 
-                                        row.names = NULL)
-      #colnames(ciAvgRdrEachTrtRRRC) <- c("Treatment", "Area", "StdErr", "DF", "CILower", "CIUpper")
+                                        stringsAsFactors = FALSE)
+      
     } else {
       fRRRC <- NA
       ddfRRRC <- NA
@@ -210,18 +264,26 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
       ciDiffTrtRRRC <- NA
       ciAvgRdrEachTrtRRRC <- NA
     }
-    if (option == "RRRC"){
-      return(list(fomArray = fomArray, msT = msT, msTR = msTR, varComp = varComp, 
-                  fRRRC = fRRRC, ddfRRRC = ddfRRRC, pRRRC = pRRRC, ciDiffTrtRRRC = ciDiffTrtRRRC, ciAvgRdrEachTrtRRRC = ciAvgRdrEachTrtRRRC))
+    if (analysisOption == "RRRC"){
+      return(list(fomArray = fomArray, 
+                  msT = msT, 
+                  msTR = msTR, 
+                  varComp = varComp, 
+                  fRRRC = fRRRC, 
+                  ddfRRRC = ddfRRRC, 
+                  pRRRC = pRRRC, 
+                  ciDiffTrtRRRC = ciDiffTrtRRRC, 
+                  ciAvgRdrEachTrtRRRC = ciAvgRdrEachTrtRRRC)
+      )
     }
   }
   
   # ************ FRRC ****************
-  if (option %in% c("FRRC", "ALL")) {
+  if (analysisOption %in% c("FRRC", "ALL")) {
     if (J > 1) {
-      msDenFRRC <- var - cov1 + (J - 1) * (cov2 - cov3)
+      msDenFRRC <- Var - Cov1 + (J - 1) * (Cov2 - Cov3)
     } else {
-      msDenFRRC <- var - cov1
+      msDenFRRC <- Var - Cov1
     }
     fFRRC <- msNum/msDenFRRC
     ddfFRRC <- Inf
@@ -235,6 +297,9 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
       tPr[i] <- 2 * pt(abs(tStat[i]), ddfFRRC, lower.tail = FALSE)  # critical correction, noted by user Lucy D'Agostino McGowan
       CIFRRC[i, ] <- sort(c(diffTRMeans[i] - qt(alpha/2, ddfFRRC) * stdErrFRRC, diffTRMeans[i] + qt(alpha/2, ddfFRRC) * stdErrFRRC))
     }
+    # for (i in (1:length(diffTRName))) {
+    #   diffTRName[i] <- paste0(paste0("Row",i,"-"),diffTRName[i])
+    # }
     ciDiffTrtFRRC <- data.frame(Treatment = diffTRName, 
                                 Estimate = diffTRMeans, 
                                 StdErr = rep(stdErrFRRC, choose(I, 2)), 
@@ -242,8 +307,10 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
                                 t = tStat, 
                                 PrGTt = tPr, 
                                 CILower = CIFRRC[,1],
-                                CIUpper = CIFRRC[,2])
-    colnames(ciDiffTrtFRRC) <- c("Treatment", "Estimate", "StdErr", "DF", "t", "PrGTt", "CILower", "CIUpper")
+                                CIUpper = CIFRRC[,2],
+                                stringsAsFactors = FALSE)
+    
+    # colnames(ciDiffTrtFRRC) <- c("Treatment", "Estimate", "StdErr", "DF", "t", "PrGTt", "CILower", "CIUpper")
     
     dfSingleFRRC <- array(dim = I)
     msDenSingleFRRC <- array(dim = I)
@@ -261,7 +328,9 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
                                       DF = as.vector(dfSingleFRRC), 
                                       CILower = CISingleFRRC[,1], 
                                       CIUpper = CISingleFRRC[,2], 
-                                      row.names = NULL)
+                                      row.names = NULL,
+                                      stringsAsFactors = FALSE)
+    
     #colnames(ciAvgRdrEachTrtFRRC) <- c("Treatment", "Area", "StdErr", "DF", "CILower", "CIUpper")
     
     diffTRMeansFRRC <- array(dim = c(J, choose(I, 2)))
@@ -303,12 +372,18 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
                                    t = tStat, 
                                    PrGTt = tPr, 
                                    CILower = CIReaderFRRC[,1],
-                                   CIUpper = CIReaderFRRC[,2])
+                                   CIUpper = CIReaderFRRC[,2],
+                                   stringsAsFactors = FALSE)
+    # 5/4/20 removing all this as I better understand data.frame()
+    
     #colnames(ciDiffTrtEachRdr) <- c("Reader", "Treatment", "Estimate", "StdErr", "DF", "t", "PrGTt", "CILower", "CIUpper")
     
-    varCovEachRdr <- data.frame(readerID, varEchRder, cov1EchRder)
+    varCovEachRdr <- data.frame(readerID, 
+                                varEchRder, 
+                                cov1EchRder,
+                                stringsAsFactors = FALSE)
     colnames(varCovEachRdr) <- c("Reader", "Var", "Cov1")
-    if (option == "FRRC"){
+    if (analysisOption == "FRRC"){
       return(list(fomArray = fomArray, msT = msT, msTR = msTR, varComp = varComp, 
                   fFRRC = fFRRC, ddfFRRC = ddfFRRC, pFRRC = pFRRC, ciDiffTrtFRRC = ciDiffTrtFRRC, ciAvgRdrEachTrtFRRC = ciAvgRdrEachTrtFRRC, ciDiffTrtEachRdr = ciDiffTrtEachRdr, varCovEachRdr = varCovEachRdr
       ))
@@ -316,7 +391,7 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
   }
   
   # ************ RRFC ****************
-  if (option %in% c("RRFC", "ALL")) {
+  if (analysisOption %in% c("RRFC", "ALL")) {
     if (J > 1) {
       msDenRRFC <- msTR
       fRRFC <- msNum/msDenRRFC
@@ -331,6 +406,10 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
         tPr[i] <- 2 * pt(abs(tStat[i]), ddfRRFC, lower.tail = FALSE)  # critical correction, noted by user Lucy D'Agostino McGowan
         CIRRFC[i, ] <- sort(c(diffTRMeans[i] - qt(alpha/2, ddfRRFC) * stdErrRRFC, diffTRMeans[i] + qt(alpha/2, ddfRRFC) * stdErrRRFC))
       }
+      
+      # for (i in (1:length(diffTRName))) {
+      #   diffTRName[i] <- paste0(paste0("Row",i,"-"),diffTRName[i])
+      # }
       ciDiffTrtRRFC <- data.frame(Treatment = diffTRName, 
                                   Estimate = diffTRMeans, 
                                   StdErr = rep(stdErrRRFC, choose(I, 2)), 
@@ -338,7 +417,10 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
                                   t = tStat, 
                                   PrGTt = tPr, 
                                   CILower = CIRRFC[,1],
-                                  CIUpper = CIRRFC[,2])
+                                  CIUpper = CIRRFC[,2],
+                                  stringsAsFactors = FALSE)
+      # 5/4/20 removing all this as I better understand data.frame()
+      
       #colnames(ciDiffTrtRRFC) <- c("Treatment", "Estimate", "StdErr", "DF", "t", "PrGTt", "CILower", "CIUpper")
       
       dfSingleRRFC <- array(dim = I)
@@ -357,7 +439,9 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
                                         DF = as.vector(dfSingleRRFC), 
                                         CILower = CISingleRRFC[,1], 
                                         CIUpper = CISingleRRFC[,2], 
-                                        row.names = NULL)
+                                        row.names = NULL,
+                                        stringsAsFactors = FALSE)
+      
       #colnames(ciAvgRdrEachTrtRRFC) <- c("Treatment", "Area", "StdErr", "DF", "CILower", "CIUpper")
     } else {
       fRRFC <- NA
@@ -366,7 +450,7 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
       ciDiffTrtRRFC <- NA
       ciAvgRdrEachTrtRRFC <- NA
     }
-    if (option == "RRFC"){
+    if (analysisOption == "RRFC"){
       return(list(fomArray = fomArray, msT = msT, msTR = msTR, varComp = varComp, 
                   fRRFC = fRRFC, ddfRRFC = ddfRRFC, pRRFC = pRRFC, ciDiffTrtRRFC = ciDiffTrtRRFC, ciAvgRdrEachTrtRRFC = ciAvgRdrEachTrtRRFC))
     }
@@ -399,9 +483,8 @@ StSignificanceTestingCrossedModalities <- function(crossedData, avgIndx, FOM = "
 
 #' @importFrom stats cov
 #' 
-EstimateVarCovCrossed <- function(NL, LL, lesionVector, lesionID, lesionWeight, maxNL, maxLL, FOM, avgIndx) {
+EstimateVarCovCrossed <- function(NL, LL, perCase, IDs, weights, maxNL, maxLL, FOM, avgIndx) {
   UNINITIALIZED <- RJafrocEnv$UNINITIALIZED
-  Dim <- dim(NL)
   I1 <- dim(NL)[1]
   I2 <- dim(NL)[2]
   J <- dim(NL)[3]
@@ -418,8 +501,8 @@ EstimateVarCovCrossed <- function(NL, LL, lesionVector, lesionID, lesionWeight,
             nl <- NL[i1, i2, j, -k, ]
             ll <- LL[i1, i2, j, , ]
             dim(nl) <- c(K - 1, maxNL)
-            dim(ll) <- c(K2, max(lesionVector))
-            jkFOMArray[i1, i2, j, k] <- gpfMyFOM(nl, ll, lesionVector, lesionID, lesionWeight, maxNL, maxLL, K1 - 1, K2, FOM)
+            dim(ll) <- c(K2, max(perCase))
+            jkFOMArray[i1, i2, j, k] <- MyFom_ij(nl, ll, perCase, IDs, weights, maxNL, maxLL, K1 - 1, K2, FOM)
           }
         }
       }
@@ -433,12 +516,12 @@ EstimateVarCovCrossed <- function(NL, LL, lesionVector, lesionID, lesionWeight,
             nl <- NL[i1, i2, j, -(k + K1), ]
             ll <- LL[i1, i2, j, -k, ]
             dim(nl) <- c(K - 1, maxNL)
-            dim(ll) <- c(K2 - 1, max(lesionVector))
-            lesionIDJk <- lesionID[-k, ]
-            dim(lesionIDJk) <- c(K2 -1, max(lesionVector))
-            lesionWeightJk <- lesionWeight[-k, ]
-            dim(lesionWeightJk) <- c(K2 -1, max(lesionVector))
-            jkFOMArray[i1, i2, j, k] <- gpfMyFOM(nl, ll, lesionVector[-k], lesionIDJk, lesionWeightJk, maxNL, maxLL, K1, K2 - 1, FOM)
+            dim(ll) <- c(K2 - 1, max(perCase))
+            lesionIDJk <- IDs[-k, ]
+            dim(lesionIDJk) <- c(K2 -1, max(perCase))
+            lesionWeightJk <- weights[-k, ]
+            dim(lesionWeightJk) <- c(K2 -1, max(perCase))
+            jkFOMArray[i1, i2, j, k] <- MyFom_ij(nl, ll, perCase[-k], lesionIDJk, lesionWeightJk, maxNL, maxLL, K1, K2 - 1, FOM)
           }
         }
       }
@@ -453,24 +536,25 @@ EstimateVarCovCrossed <- function(NL, LL, lesionVector, lesionID, lesionWeight,
               nl <- NL[i1, i2, j, -k, ]
               ll <- LL[i1, i2, j, , ]
               dim(nl) <- c(K - 1, maxNL)
-              dim(ll) <- c(K2, max(lesionVector))
-              jkFOMArray[i1, i2, j, k] <- gpfMyFOM(nl, ll, lesionVector, lesionID, lesionWeight, maxNL, maxLL, K1 - 1, K2, FOM)
+              dim(ll) <- c(K2, max(perCase))
+              jkFOMArray[i1, i2, j, k] <- MyFom_ij(nl, ll, perCase, IDs, weights, maxNL, maxLL, K1 - 1, K2, FOM)
             } else {
               nl <- NL[i1, i2, j, -k, ]
               ll <- LL[i1, i2, j, -(k - K1), ]
               dim(nl) <- c(K - 1, maxNL)
-              dim(ll) <- c(K2 - 1, max(lesionVector))
-              lesionIDJk <- lesionID[-(k - K1), ]
-              dim(lesionIDJk) <- c(K2 -1, max(lesionVector))
-              lesionWeightJk <- lesionWeight[-(k - K1), ]
-              dim(lesionWeightJk) <- c(K2 -1, max(lesionVector))
-              jkFOMArray[i1, i2, j, k] <- gpfMyFOM(nl, ll, lesionVector[-(k - K1)], lesionIDJk, lesionWeightJk, maxNL, maxLL, K1, K2 - 1, FOM)
+              dim(ll) <- c(K2 - 1, max(perCase))
+              lesionIDJk <- IDs[-(k - K1), ]
+              dim(lesionIDJk) <- c(K2 -1, max(perCase))
+              lesionWeightJk <- weights[-(k - K1), ]
+              dim(lesionWeightJk) <- c(K2 -1, max(perCase))
+              jkFOMArray[i1, i2, j, k] <- MyFom_ij(nl, ll, perCase[-(k - K1)], lesionIDJk, lesionWeightJk, maxNL, maxLL, K1, K2 - 1, FOM)
             }
           }
         }
       }
     }
   }
+  
   K <- length(jkFOMArray[1, 1, 1, ])
   if (avgIndx == 1){
     jkFOMArray <- apply(jkFOMArray, c(2, 3, 4), mean)
@@ -479,10 +563,18 @@ EstimateVarCovCrossed <- function(NL, LL, lesionVector, lesionID, lesionWeight,
     jkFOMArray <- apply(jkFOMArray, c(1, 3, 4), mean)
     fomArray <- apply(jkFOMArray, c(1, 2), mean)
   }
-  Cov <- ResamplingEstimateVarCovs(jkFOMArray)
-  var <- Cov$var * (K - 1)^2/K  # see paper by Efron and Stein
-  cov1 <- Cov$cov1 * (K - 1)^2/K
-  cov2 <- Cov$cov2 * (K - 1)^2/K
-  cov3 <- Cov$cov3 * (K - 1)^2/K
-  return(list(var = var, cov1 = cov1, cov2 = cov2, cov3 = cov3, fomArray = fomArray))
+  
+  Cov <- FOMijk2VarCov(jkFOMArray, varInflFactor = TRUE)
+  Var <- Cov$Var
+  Cov1 <- Cov$Cov1
+  Cov2 <- Cov$Cov2
+  Cov3 <- Cov$Cov3
+  
+  return(list(
+    Var = Var, 
+    Cov1 = Cov1, 
+    Cov2 = Cov2, 
+    Cov3 = Cov3, 
+    fomArray = fomArray
+  ))
 }
