@@ -6,3 +6,7 @@ double yROC(double zeta, double mu, double lambdaP, double nuP, NumericMatrix le
 double xROC(double zeta, double lambdaP);
 
 double SmAuc(double mu, double lambdaP, double nuP, NumericMatrix lesionDistribution);
+
+double ywAFROC (double zeta, double mu, double nuP,
+                NumericMatrix lesDistr, NumericMatrix lesWghtDistr);
+  
